======================
MetadataJSONReproducer
======================

.. autoclass:: openmsistream.metadata_extraction.MetadataJSONReproducer
   :private-members:
   :exclude-members: _on_check, _on_shutdown, _get_processing_result_message_for_file